%% Data assimilation with the Lorenz 1963 model
% Javier Amezcua, UMCP-AOSC, November 2011

% This file contains the controls for performing data assimilation with the
% Lorenz 1963 3-variable model using the ETKF

close all
clear all
home

%% 1. The nature run
% The maximum and the initial conditions
tmax = 10;
x0 = [-10,10,20];
% computing the nature run
[t,xt] = lorenz3v(x0,tmax);


%% 2. The observations
freqobs = 8;
L = 3; % number of observations
H = eye(L,L);
var_obs = 2; % error variance of observations (independent error assumed)
[tobs,y,R] = gen_obs(t,xt,freqobs,H,var_obs);

%% Plot to check model and obs 
figure
 for i=1:3
 subplot(3,1,i)
  plot(t,xt(:,i),'k'); hold on
  scatter(tobs,y(:,i),20,'r','filled'); hold on
 end

%% 3. The assimilation using [symmetric] ETKF
% Covariance inflation and ensemble size 
rho = 0.04; % Xb_pert -> (1+rho)*Xb_pert
% for freq obs the optimal is ~0.05
% for infreq obs the optimal is ~0.4

M = 3; 
% The ETKF
[Xb,xb,Xa,xa] = kf_lor3v(x0,t,tobs,y,H,R,rho,M);

%% Plot to check model, obs and assim 
figure
 for i=1:3
 subplot(3,1,i)
  plot(t,squeeze(Xa(:,i,:)),'m'); hold on
  plot(t,xt(:,i),'k'); hold on
  scatter(tobs,y(:,i),20,'r','filled'); hold on
  plot(t,xa(:,i),'m'); hold on
 end





